<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Versão %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 é um Software Livre, mas o seu desenvolvimento leva um tempo precioso.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Por favor, &lt;a href=&apos;%1&apos;&gt;doe&lt;/a&gt; para ajudar o desenvolvimento contínuo de %2.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Lançado sob os termos da &lt;a href=&apos;%1&apos;&gt;Licença Pública Geral GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>O que você sempre quis saber sobre o %1 e nunca ousou perguntar</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation>Você pode querer tentar os meus outros aplicativos também:</translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation>%1, uma aplicação para o YouTube</translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1, um tocador de música para YouTube</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Traduza %1 para o seu idioma nativo usando %2</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licenciado a: %1</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Entre com seus Detalhes de Licença</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>E-mail:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>Código:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Por favor, licença %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Esta demonstração expirou.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Sem licença, a aplicação irá expirar em %1 dias.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Ao comprar a versão completa, você também vai apoiar o trabalho duro eu dediquei em criar %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Usar Demonstração</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Entrar com a Licença.</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Comprar a Licença.</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation>A versão completa permite que você baixe vídeos com mais de %1 minutos e assista-os sem interrupções.</translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>Comprar em %1</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>Leia mais</translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Ano</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Popularidade</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Ordem Inversa</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Ordenar por</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>Leia mais</translation>
    </message>
</context>
<context>
    <name>ArtistListView</name>
    <message>
        <source>Track Count</source>
        <translation>Contador De Faixa</translation>
    </message>
    <message>
        <source>Album Count</source>
        <translation>Contador De Álbum</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Ano</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Popularidade</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Ordem Inversa</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Ordenar por</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Voltar</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Voltar</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bem-vindo à &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1 precisa buscar sua coleção de músicas.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>Utilizar coleção iTunes</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>Utilizar %1</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Escolher uma pasta...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1 irá conectar no serviço web Last.fm e passará os nomes dos artistas e títulos de álbuns, a fim de buscar a capa do disco, biografias e muito mais.</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>Se você tiver preocupações com a privacidade sobre isso, você pode sair agora.</translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>Onde está sua coleção de músicas?</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Selecionar o local da sua coleção de músicas.</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Localizar sua coleção</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>Uma tarefa de busca já está em execução</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>%1 está buscando sua coleção de músicas.</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>%1 está usando &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; para classificar suas músicas.</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>Isso levará algum tempo dependendo do tamanho de sua coleção e velocidade da internet.</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Vá pegar um café</translation>
    </message>
</context>
<context>
    <name>DownloadWidget</name>
    <message>
        <source>Downloading update...</source>
        <translation>Baixando atualização...</translation>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>Solte aqui para acrescentar à lista</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Artistas</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Álbuns</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Pastas</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Reproduzir/Pausar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Parar reprodução depois da faixa atual</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Próxima faixa</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Faixa anterior</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Aumentar volume</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Diminuir volume</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mudo</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Procurar para frente</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Procurar para trás</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation>Falha na autenticação</translation>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation>Entrar no %1</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Usuário:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Senha:</translation>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation>Cadastre-se para uma conta %1</translation>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation>Esqueceu seu &lt;a href=&apos;%1&apos;&gt;nome de usuário&lt;/a&gt; ou &lt;a href=&apos;%2&apos;&gt;senha&lt;/a&gt;?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Voltar</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Ir para a visualização anterior</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Informações</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Mostrar informações sobre a faixa atual</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>&amp;Anterior</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Ir para a faixa anterior</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Próximo</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Pular para a próxima faixa</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Reproduzir</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Iniciar reprodução</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Tela &amp;cheia</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Tela cheia</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>R&amp;emover</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Remover as faixas selecionadas da lista de reprodução</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mover para &amp;cima</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>Mover para cima as faixas selecionadas da lista de reprodução</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mover para &amp;baixo</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>Mover para baixo as faixas selecionadas da lista de reprodução</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Tchau</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>&amp;Alterar a pasta da coleção...</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Escolher uma outra pasta para a coleção de músicas</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>S&amp;ite</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 na Web</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Fazer uma &amp;doação</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Por favor, ajude o desenvolvimento contínuo de %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informações sobre %1</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Limpar</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Remover todas as faixas da lista de reprodução</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>&amp;Aleatório</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>Modo aleatório da lista de reprodução</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>&amp;Repetir</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Reproduzir a primeira música novamente depois de reproduzir todas as músicas</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Volume mudo</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Programa</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Reprodução</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>&amp;Lista de reprodução</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Pressionar %1 para aumentar o volume, %2 para diminuí-lo</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Abrindo %1</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>Atualizando coleção...</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>Atualizando coleção - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>Coleção atualizada</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Erro fatal: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Erro: %1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Abandonar tela &amp;cheia</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tempo restante: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volume em %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Volume está mudo</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Volume não está mudo</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Obter a versão completa</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 versão %2 está agora disponível.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Lembrar mais tarde</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Atualizar</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Janela</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimizar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Adquirir %1...</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation>&amp;Parar Depois Desta Faixa</translation>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation>&amp;Scrobbling</translation>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation>Enviar os títulos das faixas reproduzidas para %1</translation>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation>&amp;Sair de %1</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Relatar um problema...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <source>%1 finished scanning your music collection</source>
        <translation>%1 finalizou a busca de sua coleção de músicas</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Lista de reprodução concluída</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Lista de reprodução terminada</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Esta é apenas uma versão de demonstração de %1.</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Ela permite que você reproduza algumas faixas para que você possa testar o programa e veja se ela funciona.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Obter a versão completa</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Uma nova versão do %1 está disponível!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 está disponível. Você está usando %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Gostaria de fazer o download agora?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Pular esta versão.</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Me lembre mais tarde.</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Instalar atualização.</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Colar.</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation>Esta demonstração está limitada a apenas %1 faixas na lista de reprodução.</translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>A lista de reprodução está vazia</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 faixas - Tamanho total é %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation>Sua busca não teve resultados.</translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Faixas</translation>
    </message>
</context>
</TS>